intelmq.bots.parsers.sucuri package — intelmq 2.3.3.alpha1 documentation

# intelmq.bots.parsers.sucuri package

## Submodules

## intelmq.bots.parsers.sucuri.parser module

Only parses hidden iframes and conditional redirections, not Encoded javascript.

`intelmq.bots.parsers.sucuri.parser.` `BOT`

  alias of `intelmq.bots.parsers.sucuri.parser.SucuriParserBot`

class `intelmq.bots.parsers.sucuri.parser.` `MyHTMLParser`(*, convert_charrefs=True)

  Bases: `html.parser.HTMLParser`

  `handle_data`(data)
  `lsData` = ''

class `intelmq.bots.parsers.sucuri.parser.` `SucuriParserBot`(bot_id: str, start: bool = False, sighup_event=None, disable_multithreading: Optional[bool] = None)

  Bases: `intelmq.lib.bot.Bot`

  `process`()

## Module contents